@@ -22,6 +22,7 @@ from anyscale._private.anyscale_client.common import (
     RUNTIME_ENV_PACKAGE_FORMAT,
 )
 from anyscale._private.models.image_uri import ImageURI
+from anyscale._private.models.model_base import InternalListResponse, ListResponse
 from anyscale._private.utils.progress_util import (
     FileDownloadProgress,
     ProgressFileReader,
@@ -34,10 +35,11 @@ from anyscale.client.openapi_client.api.default_api import DefaultApi as Interna
 from anyscale.client.openapi_client.models import (
     ArchiveStatus,
     Cloud,
+    CloudDataBucketAccessMode,
     CloudDataBucketFileType,
-    CloudDataBucketPresignedUploadInfo,
-    CloudDataBucketPresignedUploadRequest,
-    CloudDataBucketPresignedUploadScheme,
+    CloudDataBucketPresignedUrlRequest,
+    CloudDataBucketPresignedUrlResponse,
+    CloudDataBucketPresignedUrlScheme,
     CloudNameOptions,
     ComputeTemplate,
     ComputeTemplateConfig,
@@ -46,18 +48,19 @@ from anyscale.client.openapi_client.models import (
     CreateDataset,
     CreateExperimentalWorkspace,
     CreateInternalProductionJob,
-    Dataset,
+    Dataset as InternalDataset,
     DatasetUpload,
     DecoratedComputeTemplate,
+    DecoratedSession,
     DeletedPlatformFineTunedModel,
     ExperimentalWorkspace,
     FineTunedModel,
     FinetunedmodelListResponse,
     InternalProductionJob,
     SessionSshKey,
-    SessionState,
     StartSessionOptions,
     StopSessionOptions,
+    WorkspaceDataplaneProxiedArtifacts,
 )
 from anyscale.client.openapi_client.models.create_schedule import CreateSchedule
 from anyscale.client.openapi_client.models.decorated_schedule import DecoratedSchedule
@@ -76,6 +79,8 @@ from anyscale.sdk.anyscale_client.models import (
     ClusterenvironmentbuildListResponse,
     ClusterEnvironmentBuildStatus,
     ClusterEnvironmentsQuery,
+    CreateBYODClusterEnvironment,
+    CreateBYODClusterEnvironmentConfigurationSchema,
     CreateClusterEnvironment,
     CreateClusterEnvironmentBuild,
     Job as APIJobRun,
@@ -128,11 +133,15 @@ def handle_api_exceptions(func):
     def wrapper(*args, **kwargs):
         try:
             return func(*args, **kwargs)
-        except ApiException as e:
+        except (ApiException, InternalApiException, ExternalApiException) as e:
             if e.status >= 400 and e.status < 500:
-                body_dict = json.loads(e.body)
-                msg = body_dict["error"]["detail"]
-                raise ValueError(msg) from None
+                try:
+                    body_dict = json.loads(e.body)
+                    msg = body_dict["error"]["detail"]
+                    raise ValueError(msg) from None
+                except KeyError:
+                    # ApiException doesn't conform to expected format, raise original error
+                    raise e from None
             raise e from None
 
     return wrapper
@@ -378,6 +387,7 @@ class AnyscaleClient(AnyscaleClientInterface):
             return parsed_dot_env
         return None
 
+    @handle_api_exceptions
     def get_current_workspace_cluster(self) -> Optional[Cluster]:
         # Checks for the existence of the ANYSCALE_EXPERIMENTAL_WORKSPACE_ID env var.
         if not is_anyscale_workspace():
@@ -453,6 +463,7 @@ class AnyscaleClient(AnyscaleClientInterface):
 
         return self._default_project_id_from_cloud_id[parent_cloud_id]
 
+    @handle_api_exceptions
     def get_project_id(
         self, *, parent_cloud_id: Optional[str] = None, name: Optional[str] = None
     ) -> str:
@@ -481,6 +492,7 @@ class AnyscaleClient(AnyscaleClientInterface):
 
             raise e from None
 
+    @handle_api_exceptions
     def get_cloud_id(
         self, cloud_name: Optional[str] = None, compute_config_id: Optional[str] = None
     ) -> str:
@@ -515,6 +527,7 @@ class AnyscaleClient(AnyscaleClientInterface):
         self._cloud_id_cache[cloud_name] = cloud_id
         return cloud_id
 
+    @handle_api_exceptions
     def get_cloud(self, *, cloud_id: str) -> Optional[Cloud]:
         try:
             cloud: Cloud = self._internal_api_client.get_cloud_api_v2_clouds_cloud_id_get(
@@ -527,6 +540,7 @@ class AnyscaleClient(AnyscaleClientInterface):
 
             raise e from None
 
+    @handle_api_exceptions
     def create_compute_config(
         self, config: ComputeTemplateConfig, *, name: Optional[str] = None
     ) -> Tuple[str, str]:
@@ -537,6 +551,7 @@ class AnyscaleClient(AnyscaleClientInterface):
         ).result
         return f"{result.name}:{result.version}", result.id
 
+    @handle_api_exceptions
     def get_compute_config(
         self, compute_config_id: str
     ) -> Optional[DecoratedComputeTemplate]:
@@ -550,6 +565,7 @@ class AnyscaleClient(AnyscaleClientInterface):
 
             raise e from None
 
+    @handle_api_exceptions
     def get_compute_config_id(
         self,
         compute_config_name: Optional[str] = None,
@@ -606,11 +622,13 @@ class AnyscaleClient(AnyscaleClientInterface):
 
         return self.get_default_compute_config(cloud_id=self.get_cloud_id()).id
 
+    @handle_api_exceptions
     def archive_compute_config(self, *, compute_config_id):
         self._internal_api_client.archive_compute_template_api_v2_compute_templates_compute_template_id_archive_post(
             compute_config_id
         )
 
+    @handle_api_exceptions
     def get_default_compute_config(self, *, cloud_id: str) -> ClusterCompute:
         return self._external_api_client.get_default_cluster_compute(
             cloud_id=cloud_id,
@@ -650,9 +668,11 @@ class AnyscaleClient(AnyscaleClientInterface):
 
         return default_compute_template
 
+    @handle_api_exceptions
     def get_cluster_env_build(self, build_id: str) -> Optional[ClusterEnvironmentBuild]:
         return self._external_api_client.get_cluster_environment_build(build_id).result
 
+    @handle_api_exceptions
     def get_cluster_env_build_image_uri(
         self, cluster_env_build_id: str, use_image_alias: bool = False
     ) -> Optional[ImageURI]:
@@ -670,6 +690,7 @@ class AnyscaleClient(AnyscaleClientInterface):
 
             raise e from None
 
+    @handle_api_exceptions
     def get_default_build_id(self) -> str:
         workspace_cluster = self.get_current_workspace_cluster()
         if workspace_cluster is not None:
@@ -679,6 +700,7 @@ class AnyscaleClient(AnyscaleClientInterface):
         ).result
         return result.id
 
+    @handle_api_exceptions
     def get_cluster_env_by_name(self, name: str) -> Optional[ClusterEnvironment]:
         resp = self._external_api_client.search_cluster_environments(
             ClusterEnvironmentsQuery(
@@ -691,6 +713,7 @@ class AnyscaleClient(AnyscaleClientInterface):
             return resp.results[0]
         return None
 
+    @handle_api_exceptions
     def list_cluster_env_builds(
         self, cluster_env_id: str,
     ) -> Generator[ClusterEnvironmentBuild, None, None]:
@@ -740,24 +763,61 @@ class AnyscaleClient(AnyscaleClientInterface):
         )
 
     def _find_or_create_cluster_env(
-        self, cluster_env_name: str, anonymous: bool
+        self,
+        cluster_env_name: str,
+        anonymous: bool,
+        *,
+        image_uri: Optional[str] = None,
+        registry_login_secret: Optional[str] = None,
+        ray_version: Optional[str] = None,
     ) -> ClusterEnvironment:
+        """
+        Find or create a cluster environment with the given name.
+
+        There're two possible race conditions:
+        1) A tries to create a cluster env with the same name as B, but B has already created it.
+        -> A will get a 409 conflict error and should retry to get the existing cluster env.
+        2) A and B creates two identical builds under the same cluster env. This would cause job queue to
+        reject the job submission.
+        -> Cluster env and BYOD build are created within the same transaction, so the latter one will fail
+        with a 409 conflict error. The former one will succeed and the latter one should retry to get the
+        existing cluster env.
+        """
         existing_cluster_env = self.get_cluster_env_by_name(cluster_env_name)
         if existing_cluster_env is not None:
             return existing_cluster_env
 
-        # this creates a cluster env only and it does not trigger a build to avoid the race condition
-        # when creating a cluster environment and a build at the same time and then list builds for the cluster environment later.
-        # ```
-        #     cluster_env == self._external_api_client.create_cluster_environment(..., image_uri=image_uri)
-        #     build == self._external_api_client.create_cluster_environment_build(..., cluster_env_id=cluster_env.id)
-        # ```
-        # The race condition can happen if another build for the same cluster envrionment is created between the two calls.
-        cluster_environment = self._external_api_client.create_cluster_environment(
-            CreateClusterEnvironment(name=cluster_env_name, anonymous=anonymous)
-        ).result
-        return cluster_environment
+        try:
+            if image_uri:
+                # For BYOD builds, we should create a build along with the cluster env.
+                cluster_environment = self._external_api_client.create_byod_cluster_environment(
+                    CreateBYODClusterEnvironment(
+                        name=cluster_env_name,
+                        config_json=CreateBYODClusterEnvironmentConfigurationSchema(
+                            docker_image=image_uri,
+                            ray_version=ray_version
+                            if ray_version
+                            else LATEST_RAY_VERSION,
+                            registry_login_secret=registry_login_secret,
+                        ),
+                        anonymous=anonymous,
+                    )
+                ).result
+            else:
+                cluster_environment = self._external_api_client.create_cluster_environment(
+                    CreateClusterEnvironment(name=cluster_env_name, anonymous=anonymous)
+                ).result
+            return cluster_environment
+        except ExternalApiException as e:
+            if e.status != 409:
+                raise e from None
+            # Retry to get the existing cluster env because it might be created by another process.
+            existing_cluster_env = self.get_cluster_env_by_name(cluster_env_name)
+            if existing_cluster_env is None:
+                raise e from None
+            return existing_cluster_env
 
+    @handle_api_exceptions
     def get_cluster_env_build_id_from_containerfile(
         self,
         cluster_env_name: str,
@@ -800,6 +860,7 @@ class AnyscaleClient(AnyscaleClientInterface):
 
         return build_op.cluster_environment_build_id
 
+    @handle_api_exceptions
     def get_cluster_env_build_id_from_image_uri(
         self,
         image_uri: ImageURI,
@@ -824,19 +885,36 @@ class AnyscaleClient(AnyscaleClientInterface):
                     raise RuntimeError(
                         f"Legacy cluster environment '{identifier}' is not found."
                     )
+        elif image_uri.is_default_image():
+            # Default image
+            cluster_envs = self._internal_api_client.list_application_templates_api_v2_application_templates_get(
+                image_name_contains=image_uri.image_uri
+            ).results
+            for cluster_env in cluster_envs:
+                if (
+                    cluster_env.latest_build is not None
+                    and cluster_env.latest_build.docker_image_name
+                    == image_uri.image_uri
+                ):
+                    return cluster_env.latest_build.id
+            raise RuntimeError(f"Default image '{image_uri.image_uri}' is not found.")
 
+        # BYOD image
         cluster_env_name = name if name else image_uri.to_cluster_env_name()
-        cluster_env = self._find_or_create_cluster_env(
-            cluster_env_name, anonymous=not name
-        )
         image_uri_str = str(image_uri)
-
+        cluster_env = self._find_or_create_cluster_env(
+            cluster_env_name,
+            anonymous=not name,
+            image_uri=image_uri_str,
+            registry_login_secret=registry_login_secret,
+            ray_version=ray_version,
+        )
         for build in self.list_cluster_env_builds(cluster_env.id):
             if (
                 build.docker_image_name == image_uri_str
                 and build.registry_login_secret == registry_login_secret
                 and build.status == ClusterEnvironmentBuildStatus.SUCCEEDED
-                and build.ray_version == ray_version
+                and (ray_version is None or build.ray_version == ray_version)
             ):
                 return build.id
 
@@ -854,6 +932,7 @@ class AnyscaleClient(AnyscaleClientInterface):
         assert result.completed
         return result.cluster_environment_build_id
 
+    @handle_api_exceptions
     def send_workspace_notification(
         self, notification: WorkspaceNotification,
     ):
@@ -869,6 +948,7 @@ class AnyscaleClient(AnyscaleClientInterface):
                 "This should not happen, so please contact Anyscale support."
             )
 
+    @handle_api_exceptions
     def get_service(
         self, name: str, *, cloud: Optional[str], project: Optional[str]
     ) -> Optional[ServiceModel]:
@@ -896,11 +976,13 @@ class AnyscaleClient(AnyscaleClientInterface):
 
         return service
 
+    @handle_api_exceptions
     def get_project(self, project_id: str) -> Optional[Project]:
         return self._internal_api_client.get_project_api_v2_projects_project_id_get(
             project_id
         ).result
 
+    @handle_api_exceptions
     def get_job(
         self,
         *,
@@ -942,6 +1024,7 @@ class AnyscaleClient(AnyscaleClientInterface):
 
             return result
 
+    @handle_api_exceptions
     def get_job_runs(self, job_id: str) -> List[APIJobRun]:
         job_runs: List[APIJobRun] = search_entities(
             self._external_api_client.search_jobs,
@@ -958,10 +1041,12 @@ class AnyscaleClient(AnyscaleClientInterface):
         )
         return job_runs
 
+    @handle_api_exceptions
     def rollout_service(self, model: ApplyServiceModel) -> ServiceModel:
         result: ServiceModel = self._external_api_client.rollout_service(model).result
         return result
 
+    @handle_api_exceptions
     def rollback_service(
         self, service_id: str, *, max_surge_percent: Optional[int] = None
     ) -> ServiceModel:
@@ -973,24 +1058,29 @@ class AnyscaleClient(AnyscaleClientInterface):
         )
         return result
 
+    @handle_api_exceptions
     def terminate_service(self, service_id: str) -> ServiceModel:
         result: ServiceModel = self._external_api_client.terminate_service(service_id)
         return result
 
+    @handle_api_exceptions
     def submit_job(self, model: CreateInternalProductionJob) -> InternalProductionJob:
         job: InternalProductionJob = self._internal_api_client.create_job_api_v2_decorated_ha_jobs_create_post(
             model,
         ).result
         return job
 
+    @handle_api_exceptions
     def terminate_job(self, job_id: str):
         self._external_api_client.terminate_job(job_id)
 
+    @handle_api_exceptions
     def archive_job(self, job_id: str):
         self._internal_api_client.archive_job_api_v2_decorated_ha_jobs_production_job_id_archive_post(
             job_id
         )
 
+    @handle_api_exceptions
     def upload_local_dir_to_cloud_storage(
         self,
         local_dir: str,
@@ -1008,11 +1098,12 @@ class AnyscaleClient(AnyscaleClientInterface):
             content_hash,
         ):
             file_name = RUNTIME_ENV_PACKAGE_FORMAT.format(content_hash=content_hash)
-            request = CloudDataBucketPresignedUploadRequest(
+            request = CloudDataBucketPresignedUrlRequest(
                 file_type=CloudDataBucketFileType.RUNTIME_ENV_PACKAGES,
                 file_name=file_name,
+                access_mode=CloudDataBucketAccessMode.WRITE,
             )
-            info: CloudDataBucketPresignedUploadInfo = self._internal_api_client.generate_cloud_data_bucket_presigned_upload_url_api_v2_clouds_cloud_id_generate_cloud_data_bucket_presigned_upload_url_post(
+            info: CloudDataBucketPresignedUrlResponse = self._internal_api_client.generate_cloud_data_bucket_presigned_url_api_v2_clouds_cloud_id_generate_cloud_data_bucket_presigned_url_post(
                 cloud_id, request
             ).result
 
@@ -1023,12 +1114,12 @@ class AnyscaleClient(AnyscaleClientInterface):
                 )
                 return info.file_uri
 
-            if info.upload_scheme == CloudDataBucketPresignedUploadScheme.SMART_OPEN:
-                # If the upload scheme is SMART_OPEN, upload to cloud storage using the provided bucket name, path, & environment, and the smart_open library.
+            if info.url_scheme == CloudDataBucketPresignedUrlScheme.SMART_OPEN:
+                # If the presigned URL scheme is SMART_OPEN, upload to cloud storage using the provided bucket name, path, & environment, and the smart_open library.
                 bucket_name = info.bucket_name
                 bucket_path = info.bucket_path
                 env_vars: Dict[str, str] = {
-                    "AWS_ENDPOINT_URL": info.upload_url,
+                    "AWS_ENDPOINT_URL": info.url,
                 }
 
                 with set_env(**env_vars), smart_open.open(
@@ -1037,9 +1128,9 @@ class AnyscaleClient(AnyscaleClientInterface):
                     fout.write(zip_file_bytes)
 
             else:
-                # Default to `https_put` upload scheme.
+                # Default to HTTP PUT.
                 internal_logger.debug(f"Uploading file '{file_name}' to cloud storage.")
-                requests.put(info.upload_url, data=zip_file_bytes).raise_for_status()
+                requests.put(info.url, data=zip_file_bytes).raise_for_status()
 
         return info.file_uri
 
@@ -1101,6 +1192,7 @@ class AnyscaleClient(AnyscaleClientInterface):
 
         return "\n".join(result_lines) + "\n"
 
+    @handle_api_exceptions
     def logs_for_job_run(
         self, job_run_id: str, head: bool = False, max_lines: Optional[int] = None
     ) -> str:
@@ -1117,6 +1209,7 @@ class AnyscaleClient(AnyscaleClientInterface):
             model
         ).result
 
+    @handle_api_exceptions
     def get_schedule(
         self,
         *,
@@ -1157,23 +1250,27 @@ class AnyscaleClient(AnyscaleClientInterface):
 
             return result
 
+    @handle_api_exceptions
     def set_schedule_state(self, id: str, is_paused: bool):  # noqa: A002
         self._internal_api_client.pause_cron_job_api_v2_experimental_cron_jobs_cron_job_id_pause_post(
             id, {"is_paused": is_paused}
         ).result
 
+    @handle_api_exceptions
     def trigger_schedule(self, id: str):  # noqa: A002
         self._internal_api_client.trigger_cron_job_api_v2_experimental_cron_jobs_cron_job_id_trigger_post(
             id
         )
 
-    def get_dataset(
-        self, name: str, version: Optional[int], project: Optional[str]
-    ) -> Dataset:
+    @handle_api_exceptions
+    def get_dataset(self, name: str, version: Optional[int], project: Optional[str]):
         project_id = self._source_project_id(project)
-        dataset = self._internal_api_client.find_dataset_api_v2_datasets_find_get(
+        internal_dataset = self._internal_api_client.find_dataset_api_v2_datasets_find_get(
             name=name, version=version, project_id=project_id
         ).result
+        from anyscale.llm.dataset._private.models import Dataset
+
+        dataset = Dataset.parse_from_internal_model(internal_dataset)
         return dataset
 
     def upload_dataset(
@@ -1183,7 +1280,7 @@ class AnyscaleClient(AnyscaleClientInterface):
         description: Optional[str],
         cloud: Optional[str],
         project: Optional[str],
-    ) -> Dataset:
+    ):
         # Resolve `~/.../file` to `/home/user/.../file`
         dataset_file = os.path.expanduser(dataset_file)
 
@@ -1230,8 +1327,13 @@ class AnyscaleClient(AnyscaleClientInterface):
             progress.console.print(
                 "Upload complete!", style=Style(bold=True, color="green")
             )
-        return dataset_upload.dataset
+        internal_dataset = dataset_upload.dataset
+        from anyscale.llm.dataset._private.models import Dataset
 
+        dataset = Dataset.parse_from_internal_model(internal_dataset)
+        return dataset
+
+    @handle_api_exceptions
     def download_dataset(
         self, name: str, version: Optional[int], project: Optional[str]
     ) -> bytes:
@@ -1261,19 +1363,45 @@ class AnyscaleClient(AnyscaleClientInterface):
 
         return dataset_bytes
 
-    def _source_project_id(self, project_name: Optional[str]) -> str:
-        """Sources a project ID from an optionally-provided project name."""
+    @handle_api_exceptions
+    def list_datasets(
+        self,
+        limit: Optional[int] = None,
+        after: Optional[str] = None,  # Unique ID to start listing after
+        name_contains: Optional[str] = None,
+        cloud: Optional[str] = None,
+        project: Optional[str] = None,
+    ):
+        project_id = self._source_project_id(project)
+        cloud_id = self.get_cloud_id(cloud_name=cloud) if cloud else None
+
+        def get_next_page(
+            after_id: Optional[str],
+        ) -> InternalListResponse[InternalDataset]:
+            internal_datasets: InternalListResponse = self._internal_api_client.list_datasets_api_v2_datasets_get(
+                project_id=project_id,
+                cloud_id=cloud_id,
+                name_contains=name_contains,
+                after=after_id,
+            )
+            return internal_datasets
+
+        from anyscale.llm.dataset._private.models import Dataset
+
+        list_response = ListResponse(
+            after=after, limit=limit, get_next_page=get_next_page, cls=Dataset,
+        )
+        return list_response
+
+    def _source_project_id(self, project_name: Optional[str]) -> Optional[str]:
+        """Sources a optional project ID from an optionally-provided project name."""
         if project_name:
             project_id = self._get_project_id_by_name(name=project_name)
         else:
-            _, project_id = source_cloud_id_and_project_id(
-                internal_api=self._internal_api_client,
-                external_api=self._external_api_client,
-                cloud_id=None,
-                project_id=None,
-            )
+            project_id = None
         return project_id
 
+    @handle_api_exceptions
     def get_finetuned_model(
         self, model_id: Optional[str], job_id: Optional[str]
     ) -> FineTunedModel:
@@ -1294,6 +1422,7 @@ class AnyscaleClient(AnyscaleClientInterface):
             create_experimental_workspace=model,
         ).result.id
 
+    @handle_api_exceptions
     def get_workspace(
         self,
         *,
@@ -1390,6 +1519,14 @@ class AnyscaleClient(AnyscaleClientInterface):
             },
         )
 
+    @handle_api_exceptions
+    def get_workspace_proxied_dataplane_artifacts(
+        self, workspace_id: str
+    ) -> WorkspaceDataplaneProxiedArtifacts:
+        return self._internal_api_client.get_workspace_proxied_dataplane_artifacts_api_v2_experimental_workspaces_workspace_id_proxied_dataplane_artifacts_get(
+            workspace_id
+        ).result
+
     @handle_api_exceptions
     def start_workspace(self, workspace_id: str):
         """Start a workspace."""
@@ -1420,15 +1557,15 @@ class AnyscaleClient(AnyscaleClientInterface):
         )
 
     @handle_api_exceptions
-    def get_workspace_status(self, workspace_id: str) -> SessionState:
-        workspace_model = self.get_workspace(id=workspace_id)
-        if workspace_model is None:
+    def get_workspace_cluster(self, workspace_id: str) -> Optional[DecoratedSession]:
+        workspace = self.get_workspace(id=workspace_id)
+        if not workspace:
             raise ValueError(f"Workspace '{workspace_id}' not found.")
 
-        result = self._internal_api_client.get_session_api_v2_sessions_session_id_get(
-            session_id=workspace_model.cluster_id
+        result = self._internal_api_client.get_decorated_cluster_api_v2_decorated_sessions_cluster_id_get(
+            workspace.cluster_id
         )
-        return result.result.state
+        return result.result
 
     @handle_api_exceptions
     def get_cluster_head_node_ip(self, cluster_id: str) -> str:
@@ -1457,12 +1594,14 @@ class AnyscaleClient(AnyscaleClientInterface):
         else:
             return project.name
 
+    @handle_api_exceptions
     def delete_finetuned_model(self, model_id: str) -> DeletedPlatformFineTunedModel:
         deleted_model = self._internal_api_client.delete_model_api_v2_llm_models_model_id_delete(
             model_id
         ).result
         return deleted_model
 
+    @handle_api_exceptions
     def list_finetuned_models(
         self, cloud_id: Optional[str], project_id: Optional[str], max_items: int,
     ) -> List[FineTunedModel]:
