@@ -7,15 +7,16 @@ from anyscale.client.openapi_client.models import (
     ComputeTemplateConfig,
     CreateExperimentalWorkspace,
     CreateInternalProductionJob,
-    Dataset,
     DecoratedComputeTemplate,
     DeletedPlatformFineTunedModel,
     FineTunedModel,
     InternalProductionJob,
     Project,
+    WorkspaceDataplaneProxiedArtifacts,
 )
 from anyscale.client.openapi_client.models.create_schedule import CreateSchedule
 from anyscale.client.openapi_client.models.decorated_schedule import DecoratedSchedule
+from anyscale.client.openapi_client.models.decorated_session import DecoratedSession
 from anyscale.client.openapi_client.models.production_job import ProductionJob
 from anyscale.client.openapi_client.models.session_ssh_key import SessionSshKey
 from anyscale.sdk.anyscale_client.models import (
@@ -25,7 +26,6 @@ from anyscale.sdk.anyscale_client.models import (
     ClusterEnvironment,
     Job as APIJobRun,
     ServiceModel,
-    SessionState,
 )
 from anyscale.sdk.anyscale_client.models.cluster_environment_build import (
     ClusterEnvironmentBuild,
@@ -37,7 +37,7 @@ from anyscale.utils.workspace_notification import WorkspaceNotification
 # Maybe just make it part of the release process to update it, or fetch the
 # default builds and get the latest one. The best thing to do is probably
 # to populate this in the backend.
-DEFAULT_RAY_VERSION = "2.37.0"
+DEFAULT_RAY_VERSION = "2.38.0"  # RAY_RELEASE_UPDATE: update to latest version.
 DEFAULT_PYTHON_VERSION = "py311"
 RUNTIME_ENV_PACKAGE_FORMAT = "pkg_{content_hash}.zip"
 
@@ -412,9 +412,7 @@ class AnyscaleClientInterface(ABC):
         raise NotImplementedError
 
     @abstractmethod
-    def get_dataset(
-        self, name: str, version: Optional[int], project: Optional[str]
-    ) -> Dataset:
+    def get_dataset(self, name: str, version: Optional[int], project: Optional[str]):
         """See docstring for `anyscale.llm.dataset.get()`."""
         raise NotImplementedError
 
@@ -426,7 +424,7 @@ class AnyscaleClientInterface(ABC):
         description: Optional[str],
         cloud: Optional[str],
         project: Optional[str],
-    ) -> Dataset:
+    ):
         """See docstring for `anyscale.llm.dataset.upload()`."""
         raise NotImplementedError
 
@@ -436,6 +434,18 @@ class AnyscaleClientInterface(ABC):
     ) -> bytes:
         """See docstring for `anyscale.llm.dataset.download()`."""
 
+    @abstractmethod
+    def list_datasets(
+        self,
+        limit: Optional[int] = None,
+        after: Optional[str] = None,  # Unique ID to start listing after
+        name_contains: Optional[str] = None,
+        cloud: Optional[str] = None,
+        project: Optional[str] = None,
+    ):
+        """See docstring for `anyscale.llm.dataset.list()`."""
+        raise NotImplementedError
+
     @abstractmethod
     def create_workspace(self, model: CreateExperimentalWorkspace) -> str:
         """Creates a workspace
@@ -491,8 +501,15 @@ class AnyscaleClientInterface(ABC):
         raise NotImplementedError
 
     @abstractmethod
-    def get_workspace_status(self, workspace_id: str) -> SessionState:
-        """Get the status of a workspace."""
+    def get_workspace_cluster(self, workspace_id: str) -> Optional[DecoratedSession]:
+        """Get the cluster model for the provided workspace ID."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def get_workspace_proxied_dataplane_artifacts(
+        self, workspace_id: str
+    ) -> WorkspaceDataplaneProxiedArtifacts:
+        """Get the dataplane artifacts of the workspace."""
         raise NotImplementedError
 
     @abstractmethod
