@@ -2,6 +2,7 @@ from collections import defaultdict
 from datetime import datetime
 import logging
 from typing import DefaultDict, Dict, Generator, List, Optional, Tuple
+from unittest.mock import Mock
 import uuid
 
 from anyscale._private.anyscale_client.common import (
@@ -9,13 +10,13 @@ from anyscale._private.anyscale_client.common import (
     WORKSPACE_CLUSTER_NAME_PREFIX,
 )
 from anyscale._private.models.image_uri import ImageURI
+from anyscale._private.models.model_base import ListResponse
 from anyscale.cli_logger import BlockLogger
 from anyscale.client.openapi_client.models import (
     Cloud,
     ComputeTemplateConfig,
     CreateExperimentalWorkspace,
     CreateInternalProductionJob,
-    Dataset,
     DecoratedComputeTemplate,
     DeletedPlatformFineTunedModel,
     ExperimentalWorkspace,
@@ -27,11 +28,14 @@ from anyscale.client.openapi_client.models import (
     ProductionJob,
     ProductionJobStateTransition,
     Project,
+    WorkspaceDataplaneProxiedArtifacts,
 )
 from anyscale.client.openapi_client.models.create_schedule import CreateSchedule
 from anyscale.client.openapi_client.models.decorated_schedule import DecoratedSchedule
+from anyscale.client.openapi_client.models.decorated_session import DecoratedSession
 from anyscale.client.openapi_client.models.session_ssh_key import SessionSshKey
 from anyscale.cluster_compute import parse_cluster_compute_name_version
+from anyscale.llm.dataset._private.models import Dataset
 from anyscale.sdk.anyscale_client.configuration import Configuration
 from anyscale.sdk.anyscale_client.models import (
     ApplyServiceModel,
@@ -823,7 +827,7 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
     def get_dataset(
         self, name: str, version: Optional[int], project: Optional[str]  # noqa: ARG002
     ) -> Dataset:
-        pass
+        raise NotImplementedError
 
     def upload_dataset(
         self,
@@ -833,13 +837,23 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
         cloud: Optional[str],  # noqa: ARG002
         project: Optional[str],  # noqa: ARG002
     ) -> Dataset:
-        pass
+        raise NotImplementedError
 
     def download_dataset(
         self, name: str, version: Optional[int], project: Optional[str]  # noqa: ARG002
     ) -> bytes:
         return b""
 
+    def list_datasets(
+        self,
+        limit: Optional[int] = None,  # noqa: ARG002
+        after: Optional[str] = None,  # noqa: ARG002
+        name_contains: Optional[str] = None,  # noqa: ARG002
+        cloud: Optional[str] = None,  # noqa: ARG002
+        project: Optional[str] = None,  # noqa: ARG002
+    ) -> ListResponse[Dataset]:
+        raise NotImplementedError
+
     def get_finetuned_model(
         self, model_id: Optional[str], job_id: Optional[str]  # noqa: ARG002
     ) -> FineTunedModel:
@@ -935,11 +949,31 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
     ):
         self._workspaces_env_vars[workspace_id] = env_vars
 
-    def get_workspace_status(self, workspace_id: str) -> SessionState:
-        workspace = self._workspaces.get(workspace_id, None)
-        if workspace is None:
-            raise ValueError(f"Workspace '{workspace_id}' not found.")
-        return workspace.state
+    def get_workspace_cluster(self, workspace_id: str) -> Optional[DecoratedSession]:
+        workspace_model = self._workspaces.get(workspace_id, None)
+        compute_config = self.get_compute_config(workspace_model.compute_config_id)
+        assert compute_config is not None
+        return Mock(
+            name=f"workspace-cluster-{workspace_model.name}",
+            build_id=workspace_model.environment_id,
+            state=workspace_model.state,
+            project_id=workspace_model.project_id,
+            cloud_id=workspace_model.cloud_id,
+            idle_timeout=compute_config.idle_timeout_minutes,
+        )
+
+    def get_workspace_proxied_dataplane_artifacts(
+        self, workspace_id: str
+    ) -> WorkspaceDataplaneProxiedArtifacts:
+        env_vars_dict = self._workspaces_env_vars.get(workspace_id, None)
+        return WorkspaceDataplaneProxiedArtifacts(
+            requirements=self._workspaces_dependencies.get(workspace_id, None),
+            environment_variables=[
+                f"{key}={value}" for key, value in env_vars_dict.items()
+            ]
+            if env_vars_dict
+            else None,
+        )
 
     def get_cluster_head_node_ip(self, cluster_id: str) -> str:
         return self._clusters_headnode_ip.get(cluster_id, "")
