@@ -21,7 +21,7 @@ from anyscale.commands.util import AnyscaleCommand, LegacyAnyscaleCommand
 
 ModelType = Union[ModelBaseType, ModelEnumType]
 
-CLI_OPTIONS_TO_SKIP = {"help", "service_id", "project_id"}
+CLI_OPTIONS_TO_SKIP = {"help"}
 CLI_NO_EXAMPLES = {
     "anyscale",
     "anyscale cloud",
