@@ -1,4 +1,4 @@
-from typing import Any, cast, Dict, List, Optional, Tuple
+from typing import Any, cast, Dict, List, Optional, Tuple, Union
 
 import click
 from click import ClickException
@@ -7,6 +7,10 @@ from openapi_client.rest import ApiException
 from anyscale.authenticate import get_auth_api_client
 from anyscale.cli_logger import BlockLogger
 from anyscale.client.openapi_client.api.default_api import DefaultApi
+from anyscale.client.openapi_client.models import (
+    CreateCloudResource,
+    CreateCloudResourceGCP,
+)
 from anyscale.sdk.anyscale_client.models.cloud import Cloud
 
 
@@ -90,6 +94,25 @@ def get_cloud_id_and_name(
     return cloud.id, cloud.name
 
 
+def get_cloud_resource_by_cloud_id(
+    cloud_id: str, cloud_provider: str, anyscale_api_client: Optional[DefaultApi] = None
+) -> Union[CreateCloudResource, CreateCloudResourceGCP]:
+    if anyscale_api_client is None:
+        anyscale_api_client = get_auth_api_client().anyscale_api_client
+    cloud_resource = None
+    if cloud_provider == "AWS":
+        cloud = anyscale_api_client.get_cloud_with_cloud_resource_api_v2_clouds_with_cloud_resource_router_cloud_id_get(
+            cloud_id
+        ).result
+        cloud_resource = cloud.cloud_resource
+    elif cloud_provider == "GCP":
+        cloud = anyscale_api_client.get_cloud_with_cloud_resource_api_v2_clouds_with_cloud_resource_gcp_router_cloud_id_get(
+            cloud_id
+        ).result
+        cloud_resource = cloud.cloud_resource
+    return cloud_resource
+
+
 def get_last_used_cloud(
     project_id: Optional[str], anyscale_api_client: Optional[DefaultApi] = None
 ) -> str:
@@ -102,6 +125,8 @@ def get_last_used_cloud(
         Name of the cloud last used in this project.
 
     TODO(nikita): Condense with anyscale.connect after unifying logging.
+    TODO: get_selected_cloud_id_or_default should be the preferred way of
+    getting a cloud in CLI code.
     """
     if anyscale_api_client is None:
         anyscale_api_client = get_auth_api_client().anyscale_api_client
@@ -179,3 +204,13 @@ def get_organization_default_cloud(api_client: DefaultApi) -> Optional[str]:
         except Exception:  # noqa: BLE001
             return None
     return None
+
+
+def get_organization_id(api_client: DefaultApi) -> str:
+    user = api_client.get_user_info_api_v2_userinfo_get().result
+    if user.organizations:
+        organization = user.organizations[0]  # Each user only has one org
+        return organization.id
+    raise click.ClickException(
+        "No organization found. Please contact Anyscale support for help."
+    )
