@@ -535,7 +535,7 @@ def cloud_config_update(
 )
 @click.option(
     "--nfs-mount-path",
-    help="The path of the NFS server to mount from (e.g. <nfs-target-address>/<nfs-path> will be mounted).",
+    help="The path of the NFS server to mount from (e.g. nfs-target-address/nfs-path will be mounted).",
     required=False,
     type=str,
 )
@@ -551,12 +551,6 @@ def cloud_config_update(
     required=False,
     type=str,
 )
-@click.option(
-    "--kubernetes-namespaces",
-    help="On the Kubernetes compute stack, a comma-separated list of namespace(s) that can be used for running workloads. The first namespace in the list will be used as the default.",
-    required=False,
-    type=str,
-)
 @click.option(
     "--kubernetes-ingress-external-address",
     help="On the Kubernetes compute stack, the address of the ingress used for serving traffic for Anyscale services.",
@@ -570,8 +564,8 @@ def cloud_config_update(
     type=str,
 )
 @click.option(
-    "--kubernetes-dataplane-identity",
-    help="On the Kubernetes compute stack, the IAM identity for the Kubernetes Manager deployment. IN AWS EKS, this is the ARN of the IAM role associated with the Kubernetes Manager deployment. For GCP GKE, this is the service account email associated with the Kubernetes Manager deployment.",
+    "--anyscale-operator-iam-identity",
+    help="On the Kubernetes compute stack, the cloud provider IAM identity federated with the Anyscale Operator's kubernetes service account, which will be used by Anyscale control plane for validation during Anyscale Operator bootstrap in the dataplane. IN AWS EKS, this is the ARN of the IAM role. For GCP GKE, this is the service account email.",
     required=False,
     type=str,
 )
@@ -636,10 +630,9 @@ def register_cloud(  # noqa: PLR0913, PLR0912
     nfs_mount_path: str,
     memorystore_instance_name: str,
     host_project_id: Optional[str],
-    kubernetes_namespaces: Optional[str],
     kubernetes_ingress_external_address: Optional[str],
     kubernetes_zones: Optional[str],
-    kubernetes_dataplane_identity: Optional[str],
+    anyscale_operator_iam_identity: Optional[str],
     functional_verify: Optional[str],
     private_network: bool,
     yes: bool,
@@ -663,7 +656,6 @@ def register_cloud(  # noqa: PLR0913, PLR0912
             (instance_iam_role_id, "--instance-iam-role-id", (ComputeStack.VM)),
             (security_group_ids, "--security-group-ids", (ComputeStack.VM)),
             (s3_bucket_id, "--s3-bucket-id", (ComputeStack.VM, ComputeStack.K8S)),
-            (kubernetes_namespaces, "--kubernetes-namespaces", (ComputeStack.K8S)),
             (
                 kubernetes_ingress_external_address,
                 "--kubernetes-ingress-external-address",
@@ -671,8 +663,8 @@ def register_cloud(  # noqa: PLR0913, PLR0912
             ),
             (kubernetes_zones, "--kubernetes-zones", (ComputeStack.K8S)),
             (
-                kubernetes_dataplane_identity,
-                "--kubernetes-dataplane-identity",
+                anyscale_operator_iam_identity,
+                "--anyscale-operator-iam-identity",
                 (ComputeStack.K8S),
             ),
         ]:
@@ -697,12 +689,9 @@ def register_cloud(  # noqa: PLR0913, PLR0912
             s3_bucket_id=s3_bucket_id,
             memorydb_cluster_id=memorydb_cluster_id,
             functional_verify=functional_verify,
-            kubernetes_namespaces=kubernetes_namespaces.split(",")
-            if kubernetes_namespaces
-            else [],
             kubernetes_ingress_external_address=kubernetes_ingress_external_address,
             kubernetes_zones=kubernetes_zones.split(",") if kubernetes_zones else [],
-            kubernetes_dataplane_identity=kubernetes_dataplane_identity,
+            anyscale_operator_iam_identity=anyscale_operator_iam_identity,
             private_network=private_network,
             cluster_management_stack_version=ClusterManagementStackVersions.V2,
             yes=yes,
@@ -737,7 +726,6 @@ def register_cloud(  # noqa: PLR0913, PLR0912
                 "--cloud-storage-bucket-name",
                 (ComputeStack.VM, ComputeStack.K8S),
             ),
-            (kubernetes_namespaces, "--kubernetes-namespaces", (ComputeStack.K8S)),
             (
                 kubernetes_ingress_external_address,
                 "--kubernetes-ingress-external-address",
@@ -745,8 +733,8 @@ def register_cloud(  # noqa: PLR0913, PLR0912
             ),
             (kubernetes_zones, "--kubernetes-zones", (ComputeStack.K8S)),
             (
-                kubernetes_dataplane_identity,
-                "--kubernetes-dataplane-identity",
+                anyscale_operator_iam_identity,
+                "--anyscale-operator-iam-identity",
                 (ComputeStack.K8S),
             ),
         ]:
@@ -808,12 +796,9 @@ def register_cloud(  # noqa: PLR0913, PLR0912
             cloud_storage_bucket_name=cloud_storage_bucket_name,
             memorystore_instance_name=memorystore_instance_name,
             host_project_id=host_project_id,
-            kubernetes_namespaces=kubernetes_namespaces.split(",")
-            if kubernetes_namespaces
-            else [],
             kubernetes_ingress_external_address=kubernetes_ingress_external_address,
             kubernetes_zones=kubernetes_zones.split(",") if kubernetes_zones else [],
-            kubernetes_dataplane_identity=kubernetes_dataplane_identity,
+            anyscale_operator_iam_identity=anyscale_operator_iam_identity,
             functional_verify=functional_verify,
             private_network=private_network,
             cluster_management_stack_version=ClusterManagementStackVersions.V2,
@@ -822,7 +807,7 @@ def register_cloud(  # noqa: PLR0913, PLR0912
             auto_add_user=enable_auto_add_user,
         )
     elif provider == "generic":
-        # For the 'generic' provider type, for the time being, most fields are optional; only 'name', 'provider', 'compute-stack', and 'kubernetes-namespaces' are required.
+        # For the 'generic' provider type, for the time being, most fields are optional; only 'name', 'provider', and 'compute-stack' are required.
         if not name:
             raise click.ClickException("Please provide a value for --name.")
 
@@ -831,11 +816,6 @@ def register_cloud(  # noqa: PLR0913, PLR0912
                 "--compute-stack=k8s must be passed for registering generic Anyscale clouds."
             )
 
-        if not kubernetes_namespaces:
-            raise click.ClickException(
-                "Please provide at least one namespace to `--kubernetes-namespaces`."
-            )
-
         CloudController().register_generic_cloud(
             name=name,
             auto_add_user=enable_auto_add_user,
@@ -844,7 +824,6 @@ def register_cloud(  # noqa: PLR0913, PLR0912
             cloud_storage_bucket_endpoint=cloud_storage_bucket_endpoint,
             nfs_mount_targets=list(nfs_mount_target) if nfs_mount_target else [],
             nfs_mount_path=nfs_mount_path,
-            kubernetes_namespaces=kubernetes_namespaces.split(","),
             kubernetes_ingress_external_address=kubernetes_ingress_external_address,
             kubernetes_zones=kubernetes_zones.split(",") if kubernetes_zones else [],
         )
