@@ -9,7 +9,11 @@ import yaml
 
 from anyscale._private.models.image_uri import ImageURI
 from anyscale.cli_logger import BlockLogger
-from anyscale.commands.util import convert_kv_strings_to_dict, LegacyAnyscaleCommand
+from anyscale.commands.util import (
+    convert_kv_strings_to_dict,
+    LegacyAnyscaleCommand,
+    override_env_vars,
+)
 from anyscale.controllers.service_controller import ServiceController
 import anyscale.service
 from anyscale.service import ServiceConfig, ServiceState, ServiceStatus
@@ -105,7 +109,7 @@ def _read_name_from_config_file(path: str):
     required=False,
     default=None,
     type=str,
-    help="Path to a local directory that will be the working directory for the service. The files in the directory will be automatically uploaded to cloud storage. When running in a workspace, this defaults to the current working directory.",
+    help="Path to a local directory or a remote URI to a .zip file (S3, GS, HTTP) that will be the working directory for the service. The files in the directory will be automatically uploaded to cloud storage. When running in a workspace, this defaults to the current working directory.",
 )
 @click.option(
     "-e",
@@ -286,9 +290,7 @@ def deploy(  # noqa: PLR0912, PLR0913 C901
         config = config.options(requirements=requirements)
 
     if env:
-        env_dict = convert_kv_strings_to_dict(env)
-        if env_dict:
-            config = config.options(env_vars=env_dict)
+        config = override_env_vars(config, convert_kv_strings_to_dict(env))
 
     if py_module:
         for module in py_module:
