@@ -1,9 +1,12 @@
+from io import StringIO
+from json import dumps as json_dumps
 import pathlib
 import subprocess
 import tempfile
 from typing import Optional, Tuple
 
 import click
+import yaml
 
 from anyscale._private.models.image_uri import ImageURI
 from anyscale._private.sdk import _LAZY_SDK_SINGLETONS
@@ -15,6 +18,7 @@ from anyscale.workspace._private.workspace_sdk import ANYSCALE_WORKSPACES_SSH_OP
 from anyscale.workspace.commands import _WORKSPACE_SDK_SINGLETON_KEY
 from anyscale.workspace.models import (
     UpdateWorkspaceConfig,
+    Workspace,
     WorkspaceConfig,
     WorkspaceState,
 )
@@ -784,3 +788,63 @@ def update(  # noqa: PLR0913, PLR0912
 
     # Apply the update
     anyscale.workspace.update(id=workspace_id, config=config)
+
+
+@workspace_cli.command(
+    name="get", short_help="Get a workspace.", cls=AnyscaleCommand,
+)
+@click.option(
+    "--id", "--workspace-id", required=False, help="Unique ID of the workspace."
+)
+@click.option("--name", "-n", required=False, help="Name of the workspace.")
+@click.option(
+    "--cloud",
+    required=False,
+    default=None,
+    type=str,
+    help="The Anyscale Cloud to run this workload on. If not provided, the organization default will be used.",
+)
+@click.option(
+    "--project",
+    required=False,
+    default=None,
+    type=str,
+    help="Named project to use for the workpsace. If not provided, the default project for the cloud will be used.",
+)
+@click.option(
+    "-j",
+    "--json",
+    is_flag=True,
+    default=False,
+    help="Output the workspace in a structured JSON format.",
+)
+@click.option(
+    "-v", "--verbose", is_flag=True, default=False, help="Include verbose details.",
+)
+def get(
+    id: Optional[str],  # noqa: A002
+    name: Optional[str],
+    cloud: Optional[str],
+    project: Optional[str],
+    json: bool,
+    verbose: bool,
+) -> None:
+    """Retrieve workspace details by name or ID.
+
+    Use --name to specify by name or --id for the workspace ID; using both will result in an error.
+    """
+    _validate_workspace_name_and_id(name=name, id=id)
+    workspace: Workspace = anyscale.workspace.get(
+        name=name, id=id, cloud=cloud, project=project
+    )
+    workspace_dict = workspace.to_dict()
+
+    if not verbose:
+        workspace_dict.pop("config", None)
+
+    if json:
+        print(json_dumps(workspace_dict, indent=4, sort_keys=False))
+    else:
+        stream = StringIO()
+        yaml.safe_dump(workspace_dict, stream, sort_keys=False)
+        print(stream.getvalue(), end="")
