@@ -51,7 +51,7 @@ MAXIMUM_UPTIME_MINUTES = 15
 IDLE_TERMINATION_MINUTES = 5
 HEAD_NODE_TYPE_AWS = "m5.xlarge"  # on demand price ~$0.20 per hour
 HEAD_NODE_TYPE_GCP = "n1-standard-2"  # on demand price ~$0.11 per hour
-CREATE_COMPUTE_CONFIG_TIMEOUT_SECONDS = 300  # 5 minutes
+CREATE_COMPUTE_CONFIG_TIMEOUT_SECONDS = 600  # 10 minutes
 
 # Workspace verification will fail fast if any of the following logs are found
 WORKSPACE_FAIL_FAST_MATCHING_LOGS = ["Failed to execute"]
@@ -162,6 +162,8 @@ class CloudFunctionalVerificationController(BaseController):
                 }
             }
 
+        # Add retries with exponential backoff here to handle the case where
+        # the cloud admin zone is not ready yet.
         start_time = time.time()
         end_time = start_time + CREATE_COMPUTE_CONFIG_TIMEOUT_SECONDS
 
@@ -177,11 +179,9 @@ class CloudFunctionalVerificationController(BaseController):
                     )
                 ).result
                 return cluster_compute.id
-            except ClickException as e:
-                if "Stream removed" not in str(e):
-                    # "Stream removed" is a known issue that ingress for CM is not ready yet
-                    # We should retry here
-                    raise e
+            except ClickException:
+                # Retry if the cloud admin zone is not ready yet
+                pass
             delay = min(delay, max_delay)
             # Add jitter to avoid synchronized retries
             jitter = random.uniform(0, delay / 2)
