@@ -79,7 +79,6 @@ class ClusterController(BaseController):
         project_id: Optional[str],
         project_name: Optional[str],
         user_service_access: Optional[str],
-        cluster_compute_version: Optional[int] = None,
     ) -> None:
         if cluster_name is not None and cluster_id is not None:
             raise click.ClickException(
@@ -121,7 +120,7 @@ class ClusterController(BaseController):
         cluster_compute_id, cluster_compute_config = None, None
         if cluster_compute_name:
             cluster_compute_id = get_cluster_compute_from_name(
-                cluster_compute_name, self.api_client, cluster_compute_version,
+                cluster_compute_name, self.api_client,
             ).id
         elif cluster_compute_file:
             cluster_compute_config = self._load_cluster_compute(cluster_compute_file)
@@ -170,7 +169,6 @@ class ClusterController(BaseController):
             cloud_name,
             existing_cluster,
             project_id,
-            cluster_compute_version,
         )
         cloud = self.anyscale_api_client.get_cloud(
             cluster_compute.config.cloud_id
@@ -570,11 +568,10 @@ class ClusterController(BaseController):
         cloud_name: Optional[str],
         existing_cluster: Optional[Cluster],
         project_id: Optional[str],
-        cluster_compute_version: Optional[int] = None,
     ) -> ComputeTemplate:
         if cluster_compute_name:
             cluster_compute = get_cluster_compute_from_name(
-                cluster_compute_name, self.api_client, cluster_compute_version,
+                cluster_compute_name, self.api_client,
             )
         elif cluster_compute_file:
             cluster_compute_config = self._load_cluster_compute(cluster_compute_file)
