@@ -78,11 +78,14 @@ class JobController(BaseController):
         log: Optional[LogsLogger] = None,
         initialize_auth_api_client: bool = True,
         raise_structured_exception: bool = False,
+        auth_token: str = None,
     ):
         if log is None:
             log = LogsLogger()
 
-        super().__init__(initialize_auth_api_client, raise_structured_exception)
+        super().__init__(
+            initialize_auth_api_client, raise_structured_exception, cli_token=auth_token
+        )
         self.log = log
         self.log.open_block("Output")
         self._cluster_journal_events_start_line = 0
