@@ -3,20 +3,28 @@ import shlex
 import subprocess
 from typing import Any, List, Optional
 
+import click
 import tabulate
 
 from anyscale.cli_logger import BlockLogger
+from anyscale.client.openapi_client.models.create_experimental_workspace import (
+    CreateExperimentalWorkspace,
+)
 from anyscale.client.openapi_client.models.experimental_workspace import (
     ExperimentalWorkspace,
 )
 from anyscale.controllers.base_controller import BaseController
 from anyscale.feature_flags import FLAG_DEFAULT_WORKING_DIR_FOR_PROJ
+from anyscale.project import get_default_project
 from anyscale.util import get_endpoint
 from anyscale.utils.workspace_utils import (
     extract_workspace_parameters,
     WorkspaceCommandContext,
 )
-from anyscale.workspace import load_workspace_id_or_throw, write_workspace_id_to_disk
+from anyscale.workspace_utils import (
+    load_workspace_id_or_throw,
+    write_workspace_id_to_disk,
+)
 
 
 ANYSCALE_WORKSPACES_SSH_OPTIONS = [
@@ -39,6 +47,41 @@ class WorkspaceController(BaseController):
         super().__init__(initialize_auth_api_client=initialize_auth_api_client)
         self.log = log
 
+    def create(
+        self,
+        name: str,
+        cloud_id: str,
+        compute_config_id: str,
+        cluster_environment_build_id: str,
+        project_id: Optional[str],
+    ) -> None:
+        compute_config = self.api_client.get_compute_template_api_v2_compute_templates_template_id_get(
+            compute_config_id
+        ).result
+
+        if compute_config.config.cloud_id != cloud_id:
+            raise click.ClickException(
+                "The compute config and cloud must be in the same cloud."
+            )
+
+        if not project_id:
+            default_project = get_default_project(
+                parent_cloud_id=cloud_id,
+                api_client=self.api_client,
+                anyscale_api_client=self.anyscale_api_client,  # type: ignore
+            )
+            project_id = default_project.id
+
+        self.api_client.create_workspace_api_v2_experimental_workspaces_post(
+            CreateExperimentalWorkspace(
+                name=name,
+                project_id=project_id,
+                cloud_id=cloud_id,
+                compute_config_id=compute_config_id,
+                cluster_environment_build_id=cluster_environment_build_id,
+            )
+        )
+
     def list(self) -> None:
         """
         prints a non-exhaustive tabular list of information about non-deleted workspaces.
@@ -139,6 +182,7 @@ class WorkspaceController(BaseController):
         down: bool,
         rsync_filters: List[str],
         rsync_excludes: List[str],
+        delete_existing_files_in_destination: bool = False,
     ) -> None:
         """
         Args:
@@ -148,6 +192,7 @@ class WorkspaceController(BaseController):
             down: Whether to sync from 1. remote to local, or 2. local to remote.
             rsync_filters: A list of rsync filters to apply.
             rsync_excludes: A list of rsync excludes to apply.
+            delete_existing_files_in_destination: Whether to delete existing files in the destination.
         """
         workspace_command_context = self._get_workspace_command_context()
         ssh_info = workspace_command_context.ssh
@@ -172,9 +217,11 @@ class WorkspaceController(BaseController):
             "--rsh",
             subprocess.list2cmdline(base_ssh_command),
             "-rvzl",
-            "--delete",
         ]
 
+        if delete_existing_files_in_destination:
+            rsync_command.append("--delete")
+
         for rsync_exclude in rsync_excludes:
             rsync_command.extend(["--exclude", rsync_exclude])
 
