@@ -104,12 +104,24 @@ class PrivateServiceSDK(WorkloadSDK):
         self, service: ServiceModel, *, canary_percent: Optional[int]
     ):
         """Log user-facing information about a deployed service."""
-        canary_percent_info = (
-            ""
-            if canary_percent is None
-            else f" (target canary percent: {canary_percent})"
+        version_id_info = "version ID: {version_id}".format(
+            version_id=self._get_user_facing_service_version_id(
+                service.canary_version
+                if service.canary_version is not None
+                else service.primary_version
+            )
         )
-        message = f"Service '{service.name}' deployed{canary_percent_info}."
+        details = (
+            "("
+            + version_id_info
+            + (
+                ")"
+                if canary_percent is None
+                else f", target canary percent: {canary_percent})"
+            )
+        )
+
+        message = f"Service '{service.name}' deployed {details}."
         self.logger.info(message)
         if self.client.inside_workspace():
             self.client.send_workspace_notification(
@@ -480,6 +492,14 @@ class PrivateServiceSDK(WorkloadSDK):
 
         return model.id
 
+    def _get_user_facing_service_version_id(
+        self, model: ProductionServiceV2VersionModel
+    ) -> str:
+        # NOTE(edoakes): the "version ID" exposed in the UI and tagged in the metrics is
+        # not actually the DB ID, but a truncated version of it. We should store this
+        # in the DB to avoid breakages, but for now I'm copying the existing logic.
+        return model.id[-self.SERVICE_VERSION_ID_TRUNCATED_LEN :]
+
     def _service_version_model_to_status(
         self,
         model: ProductionServiceV2VersionModel,
@@ -514,10 +534,7 @@ class PrivateServiceSDK(WorkloadSDK):
             )
 
         return ServiceVersionStatus(
-            # NOTE(edoakes): the "version ID" exposed in the UI and tagged in the metrics is
-            # not actually the DB ID, but a truncated version of it. We should store this
-            # in the DB to avoid breakages, but for now I'm copying the existing logic.
-            id=model.id[-self.SERVICE_VERSION_ID_TRUNCATED_LEN :],
+            id=self._get_user_facing_service_version_id(model),
             state=model.current_state,
             # NOTE(edoakes): there is also a "current_weight" field but it does not match the UI.
             weight=model.weight,
