@@ -2,7 +2,7 @@ import contextlib
 from enum import Enum
 import sys
 import time
-from typing import Optional, Tuple
+from typing import Any, Callable, Dict, List, Optional, Tuple, TypeVar
 import uuid
 
 import boto3
@@ -21,6 +21,10 @@ from anyscale.client.openapi_client.models import (
     CreateAnalyticsEvent,
 )
 from anyscale.cloud import get_cloud_id_and_name
+from anyscale.shared_anyscale_utils.utils.collections import flatten
+
+
+V = TypeVar("V")
 
 
 def get_organization_default_cloud(api_client: DefaultApi) -> Optional[str]:
@@ -86,14 +90,20 @@ def verify_anyscale_access(
         return False
 
 
-def modify_memorydb_parameter_group(parameter_group_name: str, region: str) -> None:
+def modify_memorydb_parameter_group(
+    parameter_group_name: str,
+    region: str,
+    boto3_session: Optional[boto3.Session] = None,
+) -> None:
     """
     Modify the memorydb parameter group to set the maxmemory-policy to allkeys-lru.
 
     This is not done in the cloudformation template because we have to create the paramter group first and then modify it.
     """
     try:
-        memorydb_client = boto3.client("memorydb", region_name=region)
+        if boto3_session is None:
+            boto3_session = boto3.Session()
+        memorydb_client = boto3_session.client("memorydb", region_name=region)
         memorydb_client.update_parameter_group(
             ParameterGroupName=parameter_group_name,
             ParameterNameValues=[
@@ -107,7 +117,7 @@ def modify_memorydb_parameter_group(parameter_group_name: str, region: str) -> N
         )
 
 
-def wait_for_lb_resource_termination(
+def wait_for_gcp_lb_resource_termination(
     api_client: DefaultApi,
     cloud_id: str,
     timeout_s: int = 900,  # 15 minute timeout
@@ -215,3 +225,93 @@ class CloudEventProducer:
                     )
                 )
             )
+
+
+def validate_aws_credentials(
+    logger: CloudSetupLogger, boto3_session: Optional[Any] = None
+) -> bool:
+    try:
+        if boto3_session is None:
+            boto3_session = boto3.Session()
+        boto3.client("sts").get_caller_identity()
+        return True
+    except Exception as e:  # noqa: BLE001
+        logger.error(f"Failed to validate AWS credentials: {e}")
+        return False
+
+
+def get_errored_resources_and_reasons(
+    cfn_client: Any, stack_name: str
+) -> Dict[str, str]:
+    """
+    Describes the CloudFormation stack events and extracts the failure reasons.
+    """
+    error_details: Dict[str, str] = {}
+    response = cfn_client.describe_stack_events(StackName=stack_name)
+    error_details.update(
+        extract_cloudformation_failure_reasons(response["StackEvents"])
+    )
+    while response.get("NextToken") is not None:
+        response = cfn_client.describe_stack_events(
+            StackName=stack_name, NextToken=response["NextToken"]
+        )
+        error_details.update(
+            extract_cloudformation_failure_reasons(response["StackEvents"])
+        )
+    return error_details
+
+
+def extract_cloudformation_failure_reasons(
+    events: List[Dict[str, Any]]
+) -> Dict[str, str]:
+    """
+    Extracts the failure reasons from the CloudFormation events.
+    """
+    failure_reasons: Dict[str, str] = {}
+    for event in events:
+        if event.get("ResourceStatus") == "CREATE_FAILED":
+            error_resource = event.get("LogicalResourceId", "UnknownResource")
+            error_reason = event.get("ResourceStatusReason", "Unknown reason")
+            if "Resource creation cancelled" in error_reason:
+                # Resource creation cancelled due to other resource failures.
+                # Skip this error.
+                continue
+            failure_reasons[error_resource] = error_reason
+    return failure_reasons
+
+
+def _unroll_resources_for_aws_list_call(aws_list_function: Callable, list_key: str):
+    def token_extractor(response) -> Optional[str]:
+        return response.get("NextToken")
+
+    # NOTE: `NextToken` is expected to have `str` type and therefore we have
+    #       we have to workaround its optionality by completely omitting it
+    #       from the call
+    responses = unroll_pagination(
+        lambda next_token: aws_list_function(
+            **({"NextToken": next_token} if next_token else {}),  # type: ignore
+        ),
+        token_extractor,
+    )
+
+    return flatten(*[r[list_key] for r in responses if list_key in r])
+
+
+def unroll_pagination(
+    paginated_method: Callable, next_token_extractor: Callable,
+):
+    """Handles paginated method's invocation by
+    - Repeatedly invoking the method (injecting the token from its previous response)
+    - Collecting all of the responses in a list
+    """
+
+    next_token: Optional[str] = None
+    results = []
+    while True:
+        r = paginated_method(next_token)
+        results.append(r)
+        next_token = next_token_extractor(r)
+        if not next_token:
+            break
+
+    return results
