@@ -45,3 +45,15 @@ def try_import_gcp_managed_setup_utils():
         raise click.ClickException(
             f"Import error occurred: {e}. Please install GCP-related packages with `pip install 'anyscale[gcp]'`."
         )
+
+
+def try_import_gcp_exceptions():
+    try:
+        from google.api_core.exceptions import GoogleAPICallError
+        from googleapiclient.errors import HttpError
+
+        return GoogleAPICallError, HttpError
+    except ImportError as e:
+        raise click.ClickException(
+            f"Import error occurred: {e}. Please install GCP-related packages with `pip install 'anyscale[gcp]'`."
+        )
