@@ -6,7 +6,10 @@ import click
 import pytest
 
 from anyscale.connect_utils.project import ProjectBlock
-from anyscale.sdk.anyscale_client import ComputeTemplateQuery
+from anyscale.sdk.anyscale_client import ArchiveStatus
+from anyscale.sdk.anyscale_client.models.compute_template_query import (
+    ComputeTemplateQuery,
+)
 
 
 @pytest.fixture()
@@ -56,7 +59,11 @@ def test_get_parent_cloud_id(
 ):
     mock_get_cloud_id_and_name = Mock(return_value=("mock_parent_cloud_id", ANY))
     mock_project_block.api_client.search_compute_templates_api_v2_compute_templates_search_post = Mock(
-        return_value=Mock(results=[Mock(config=Mock(cloud_id="mock_parent_cloud_id"))])
+        return_value=Mock(
+            results=[
+                Mock(config=Mock(cloud_id="mock_parent_cloud_id"), archived_at=None)
+            ]
+        )
     )
     mock_get_organization_default_cloud = Mock(return_value=None)
     mock_get_last_used_cloud = Mock(return_value="mock_parent_cloud_name")
@@ -85,6 +92,7 @@ def test_get_parent_cloud_id(
                 orgwide=True,
                 name={"equals": cluster_compute_name},
                 include_anonymous=True,
+                archive_status=ArchiveStatus.ALL,
             )
         )
     else:
