@@ -31,7 +31,7 @@ def _connected(ray: Mock, ret: Dict[str, Any],) -> Callable[[Any, Any], Dict[str
     return connected
 
 
-@pytest.fixture
+@pytest.fixture()
 def mock_interactive_session_block():
     with patch.multiple(
         "anyscale.connect_utils.start_interactive_session.StartInteractiveSessionBlock",
@@ -192,11 +192,10 @@ def test_acquire_session_lock_failure(
     with patch.multiple(
         "anyscale.connect_utils.start_interactive_session",
         check_required_ray_version=mock_check_required_ray_version,
-    ):
-        with pytest.raises(RuntimeError):
-            mock_interactive_session_block._acquire_session_lock(
-                mock_session, 0, True, False, {}
-            )
+    ), pytest.raises(RuntimeError):
+        mock_interactive_session_block._acquire_session_lock(
+            mock_session, 0, True, False, {}
+        )
     if ray_info_resp:
         mock_check_required_ray_version.assert_called_with(
             mock_interactive_session_block.log,
