@@ -15,9 +15,7 @@ from anyscale.sdk.anyscale_client import (
     CreateBYODClusterEnvironment,
     CreateClusterEnvironment,
 )
-from frontend.cli.anyscale.utils.ray_version_utils import (
-    get_correct_name_for_base_image_name,
-)
+from anyscale.utils.ray_version_utils import get_correct_name_for_base_image_name
 
 
 def get_imported_function_name(func: Callable[..., Any]) -> str:
