@@ -1,4 +1,5 @@
 from copy import deepcopy
+from dataclasses import dataclass
 import os
 from typing import Collection, Optional, Tuple
 from unittest.mock import ANY, call, Mock, patch
@@ -420,7 +421,7 @@ def test_generate_config_from_file_inside_workspace_no_working_dir_override(
 @pytest.mark.parametrize("override_name", [None, "override_service_name"])
 @pytest.mark.parametrize("override_version", [None, "override_version"])
 @pytest.mark.parametrize(
-    ("override_canary_percent"), [None, 0, 0, 40, 40],
+    ("override_canary_percent"), [None, 0, 40],
 )
 @pytest.mark.parametrize("override_rollout_strategy", [None, "IN_PLACE"])
 @pytest.mark.parametrize("auto_complete_rollout", [True, False])
@@ -507,6 +508,14 @@ def test_rollout(  # noqa: PLR0913
     )
 
 
+@dataclass
+class FakeServiceResult:
+    id: str
+    name: str
+    project_id: str = "fake-default-project-id"
+    current_state: str = "RUNNING"
+
+
 class TestGetServiceID:
     def test_invalid_inputs(self, setup_service_controller):
         service_controller, _ = setup_service_controller
@@ -568,7 +577,11 @@ class TestGetServiceID:
             service_controller.get_service_id(service_name=TEST_SERVICE_NAME)
 
         service_controller.api_client.list_services_api_v2_services_v2_get.assert_called_once_with(
-            count=10, creator_id=None, name=TEST_SERVICE_NAME, project_id=None,
+            count=10,
+            creator_id=None,
+            name=TEST_SERVICE_NAME,
+            project_id=None,
+            paging_token=None,
         )
         service_controller.api_client.list_services_api_v2_services_v2_get.reset_mock()
 
@@ -587,7 +600,11 @@ class TestGetServiceID:
             service_controller.get_service_id(service_config_file="test-config-file")
 
         service_controller.api_client.list_services_api_v2_services_v2_get.assert_called_once_with(
-            count=10, creator_id=None, name=TEST_SERVICE_NAME, project_id=None,
+            count=10,
+            creator_id=None,
+            name=TEST_SERVICE_NAME,
+            project_id=None,
+            paging_token=None,
         )
 
     def test_name_provided_single_matching_service(self, setup_service_controller):
@@ -595,7 +612,8 @@ class TestGetServiceID:
         service_controller, _ = setup_service_controller
 
         service_controller.api_client.list_services_api_v2_services_v2_get.return_value = DecoratedlistserviceapimodelListResponse(
-            results=[Mock(id=TEST_SERVICE_ID)], metadata=Mock(next_paging_token=None),
+            results=[FakeServiceResult(id=TEST_SERVICE_ID, name=TEST_SERVICE_NAME)],
+            metadata=Mock(next_paging_token=None),
         )
 
         assert (
@@ -603,7 +621,11 @@ class TestGetServiceID:
             == TEST_SERVICE_ID
         )
         service_controller.api_client.list_services_api_v2_services_v2_get.assert_called_once_with(
-            count=10, creator_id=None, name=TEST_SERVICE_NAME, project_id=None,
+            count=10,
+            creator_id=None,
+            name=TEST_SERVICE_NAME,
+            project_id=None,
+            paging_token=None,
         )
         service_controller.api_client.list_services_api_v2_services_v2_get.reset_mock()
 
@@ -619,7 +641,11 @@ class TestGetServiceID:
             == TEST_SERVICE_ID
         )
         service_controller.api_client.list_services_api_v2_services_v2_get.assert_called_once_with(
-            count=10, creator_id=None, name=TEST_SERVICE_NAME, project_id=None,
+            count=10,
+            creator_id=None,
+            name=TEST_SERVICE_NAME,
+            project_id=None,
+            paging_token=None,
         )
 
     def test_name_provided_multiple_matching_services(self, setup_service_controller):
@@ -627,7 +653,10 @@ class TestGetServiceID:
         service_controller, _ = setup_service_controller
 
         service_controller.api_client.list_services_api_v2_services_v2_get.return_value = DecoratedlistserviceapimodelListResponse(
-            results=[Mock(id="test-service-id-1"), Mock(id="test-service-id-2")],
+            results=[
+                FakeServiceResult(id="test-service-id-1", name=TEST_SERVICE_NAME),
+                FakeServiceResult(id="test-service-id-2", name=TEST_SERVICE_NAME),
+            ],
             metadata=Mock(next_paging_token=None),
         )
 
@@ -638,7 +667,11 @@ class TestGetServiceID:
             service_controller.get_service_id(service_name=TEST_SERVICE_NAME)
 
         service_controller.api_client.list_services_api_v2_services_v2_get.assert_called_once_with(
-            count=10, creator_id=None, name=TEST_SERVICE_NAME, project_id=None,
+            count=10,
+            creator_id=None,
+            name=TEST_SERVICE_NAME,
+            project_id=None,
+            paging_token=None,
         )
         service_controller.api_client.list_services_api_v2_services_v2_get.reset_mock()
 
@@ -656,7 +689,35 @@ class TestGetServiceID:
             service_controller.get_service_id(service_config_file="test-config-file")
 
         service_controller.api_client.list_services_api_v2_services_v2_get.assert_called_once_with(
-            count=10, creator_id=None, name=TEST_SERVICE_NAME, project_id=None,
+            count=10,
+            creator_id=None,
+            name=TEST_SERVICE_NAME,
+            project_id=None,
+            paging_token=None,
+        )
+
+    def test_name_provided_exact_match(self, setup_service_controller):
+        """The API uses a substring match, so ensure we filter to the exact name."""
+        service_controller, _ = setup_service_controller
+
+        service_controller.api_client.list_services_api_v2_services_v2_get.return_value = DecoratedlistserviceapimodelListResponse(
+            results=[
+                FakeServiceResult(id="test-service-id-1", name="test-service"),
+                FakeServiceResult(id="test-service-id-2", name="test-service-suffix"),
+            ],
+            metadata=Mock(next_paging_token=None),
+        )
+
+        assert (
+            service_controller.get_service_id(service_name="test-service")
+            == "test-service-id-1"
+        )
+        service_controller.api_client.list_services_api_v2_services_v2_get.assert_called_once_with(
+            count=10,
+            creator_id=None,
+            name="test-service",
+            project_id=None,
+            paging_token=None,
         )
 
     def test_no_project_id(self, setup_service_controller):
@@ -664,7 +725,8 @@ class TestGetServiceID:
         service_controller, _ = setup_service_controller
 
         service_controller.api_client.list_services_api_v2_services_v2_get.return_value = DecoratedlistserviceapimodelListResponse(
-            results=[Mock(id=TEST_SERVICE_ID)], metadata=Mock(next_paging_token=None),
+            results=[FakeServiceResult(id=TEST_SERVICE_ID, name=TEST_SERVICE_NAME)],
+            metadata=Mock(next_paging_token=None),
         )
 
         mock_infer_project_id = Mock(return_value="mock_default_project_id")
@@ -677,7 +739,11 @@ class TestGetServiceID:
                 == TEST_SERVICE_ID
             )
             service_controller.api_client.list_services_api_v2_services_v2_get.assert_called_once_with(
-                count=10, creator_id=None, name=TEST_SERVICE_NAME, project_id=None,
+                count=10,
+                creator_id=None,
+                name=TEST_SERVICE_NAME,
+                project_id=None,
+                paging_token=None,
             )
 
     def test_project_id_in_service_config(self, setup_service_controller):
@@ -685,7 +751,14 @@ class TestGetServiceID:
         service_controller, _ = setup_service_controller
 
         service_controller.api_client.list_services_api_v2_services_v2_get.return_value = DecoratedlistserviceapimodelListResponse(
-            results=[Mock(id=TEST_SERVICE_ID)], metadata=Mock(next_paging_token=None),
+            results=[
+                FakeServiceResult(
+                    id=TEST_SERVICE_ID,
+                    name=TEST_SERVICE_NAME,
+                    project_id="test-project-id",
+                )
+            ],
+            metadata=Mock(next_paging_token=None),
         )
 
         mock_service_config = Mock()
@@ -713,6 +786,7 @@ class TestGetServiceID:
                 creator_id=None,
                 name=TEST_SERVICE_NAME,
                 project_id="test-project-id",
+                paging_token=None,
             )
 
     def test_override_project_id(self, setup_service_controller):
@@ -720,7 +794,14 @@ class TestGetServiceID:
         service_controller, _ = setup_service_controller
 
         service_controller.api_client.list_services_api_v2_services_v2_get.return_value = DecoratedlistserviceapimodelListResponse(
-            results=[Mock(id=TEST_SERVICE_ID)], metadata=Mock(next_paging_token=None),
+            results=[
+                FakeServiceResult(
+                    id=TEST_SERVICE_ID,
+                    name=TEST_SERVICE_NAME,
+                    project_id="overridden-project-id",
+                )
+            ],
+            metadata=Mock(next_paging_token=None),
         )
 
         # Test overriding when getting service ID by name.
@@ -735,6 +816,7 @@ class TestGetServiceID:
             creator_id=None,
             name=TEST_SERVICE_NAME,
             project_id="overridden-project-id",
+            paging_token=None,
         )
         service_controller.api_client.list_services_api_v2_services_v2_get.reset_mock()
 
@@ -766,6 +848,7 @@ class TestGetServiceID:
             creator_id=None,
             name=TEST_SERVICE_NAME,
             project_id="overridden-project-id",
+            paging_token=None,
         )
 
 
@@ -813,7 +896,11 @@ class TestListServices:
         )
 
         service_controller.api_client.list_services_api_v2_services_v2_get.assert_called_once_with(
-            creator_id=creator_id, name=name, project_id=project_id, count=10,
+            creator_id=creator_id,
+            name=name,
+            project_id=project_id,
+            count=10,
+            paging_token=None,
         )
 
     def test_list_service_with_pagination(
@@ -841,7 +928,9 @@ class TestListServices:
         service_controller.list()
 
         calls = [
-            call(creator_id=None, name=None, project_id=None, count=10),
+            call(
+                creator_id=None, name=None, project_id=None, count=10, paging_token=None
+            ),
             call(
                 creator_id=None,
                 name=None,
