@@ -1313,13 +1313,12 @@ def test_verify_aws_efs_policy(strict: bool, policy: Optional[List[str]], capsys
     if not policy:
         assert verification_result is True
         assert "does not have sufficient permissions" not in stderr
+    elif len(policy) == 3:
+        assert verification_result is True
+        assert "does not have sufficient permissions" not in stderr
     else:
-        if len(policy) == 3:
-            assert verification_result is True
-            assert "does not have sufficient permissions" not in stderr
-        else:
-            assert verification_result == (not strict)
-            assert "does not have sufficient permissions" in stderr
+        assert verification_result == (not strict)
+        assert "does not have sufficient permissions" in stderr
 
 
 @pytest.mark.parametrize(
