@@ -2,10 +2,7 @@ import click
 import pytest
 
 from anyscale.utils.imports.all import try_import_ray
-from anyscale.utils.imports.gcp import (
-    try_import_gcp_discovery,
-    try_import_gcp_secretmanager,
-)
+from anyscale.utils.imports.gcp import try_import_gcp_secretmanager
 
 
 def test_try_import_ray():
@@ -34,13 +31,3 @@ def test_try_import_gcp_secretmanager():
     except ImportError:
         with pytest.raises(click.ClickException):
             try_import_gcp_secretmanager()
-
-
-def test_try_import_gcp_discovery():
-    try:
-        from googleapiclient import discovery
-
-        assert try_import_gcp_discovery() == discovery
-    except ImportError:
-        with pytest.raises(click.ClickException):
-            try_import_gcp_discovery()
