@@ -42,7 +42,10 @@ from anyscale.util import (
 )
 from anyscale.utils.cloud_utils import CloudSetupError
 from anyscale.utils.name_utils import gen_valid_name
-from backend.server.common.utils.constants import NAME_VALIDATION_REGEX_PATTERN
+
+
+# Keep in sync with backend.server.common.utils.constants.NAME_VALIDATION_REGEX_PATTERN
+_NAME_VALIDATION_REGEX_PATTERN = "^[A-Za-z0-9._-]+$"
 
 
 def test_updating_printer() -> None:
@@ -284,14 +287,14 @@ def test_prepare_cloudformation_template(is_anyscale_hosted):
     mock_cfn_stack_name = "mock_cfn_stack_name"
     mock_cloud_id = "mock_cloud_id"
 
-    mock_azs = [
-        "us-east-1a",
-        "us-east-1b",
-        "us-east-1c",
-        "us-east-1d",
-        "us-east-1e",
-        "us-east-1f",
-    ]
+    mock_azs = {
+        "use1-az1": "us-east-1a",
+        "use1-az2": "us-east-1b",
+        "use1-az3": "us-east-1c",
+        "use1-az4": "us-east-1d",
+        "use1-az5": "us-east-1e",
+        "use1-az6": "us-east-1f",
+    }
 
     with patch("anyscale.util.get_availability_zones", new=Mock(return_value=mock_azs)):
         cfn_template = prepare_cloudformation_template(
@@ -781,8 +784,8 @@ def test_gen_valid_name():
     name_without_prefiex = gen_valid_name()
     name_with_prefiex = gen_valid_name("test prefix name")
 
-    assert re.match(NAME_VALIDATION_REGEX_PATTERN, name_without_prefiex) is not None
-    assert re.match(NAME_VALIDATION_REGEX_PATTERN, name_with_prefiex) is not None
+    assert re.match(_NAME_VALIDATION_REGEX_PATTERN, name_without_prefiex) is not None
+    assert re.match(_NAME_VALIDATION_REGEX_PATTERN, name_with_prefiex) is not None
 
 
 @pytest.mark.parametrize(
