@@ -59,10 +59,7 @@ from anyscale.service.models import (
     ServiceVersionStatus,
     TracingConfig,
 )
-from anyscale.utils.workspace_notification import (
-    WorkspaceNotification,
-    WorkspaceNotificationAction,
-)
+from anyscale.utils.workspace_notification import WorkspaceNotificationAction
 
 
 @pytest.fixture()
@@ -842,14 +839,15 @@ class TestDeploy:
         service_id = fake_client.get_service(
             "test-service-name", cloud=None, project=None
         ).id
-        assert fake_client.sent_workspace_notifications == [
-            WorkspaceNotification(
-                body="Service 'test-service-name' deployed.",
-                action=WorkspaceNotificationAction(
-                    type="navigate-service", title="View Service", value=service_id,
-                ),
-            )
-        ]
+        assert len(fake_client.sent_workspace_notifications) == 1
+        assert fake_client.sent_workspace_notifications[
+            0
+        ].action == WorkspaceNotificationAction(
+            type="navigate-service", title="View Service", value=service_id,
+        )
+        assert fake_client.sent_workspace_notifications[0].body.startswith(
+            "Service 'test-service-name' deployed (version ID: "
+        )
 
     @pytest.mark.parametrize(
         ("state", "expected_prefix"),
