@@ -8,8 +8,12 @@ from click.testing import CliRunner
 import pytest
 
 from anyscale._private.sdk import _LAZY_SDK_SINGLETONS
+from anyscale.client.openapi_client.models.experimental_workspace import (
+    ExperimentalWorkspace,
+)
 from anyscale.commands.workspace_commands_v2 import (
     create,
+    get,
     pull,
     push,
     run_command,
@@ -23,6 +27,7 @@ from anyscale.commands.workspace_commands_v2 import (
 from anyscale.workspace.commands import _WORKSPACE_SDK_SINGLETON_KEY
 from anyscale.workspace.models import (
     UpdateWorkspaceConfig,
+    Workspace,
     WorkspaceConfig,
     WorkspaceState,
 )
@@ -53,6 +58,7 @@ class FakeWorkspaceSDK:
     def __init__(self):
         self._created_workspaces: Dict[str, WorkspaceConfig] = {}
         self._workspace_status = {}
+        self._internal_workspaces: Dict[str, ExperimentalWorkspace] = {}
 
     def _resolve_to_workspace_model(
         self,
@@ -247,6 +253,29 @@ class FakeWorkspaceSDK:
         # Save the updated configuration back
         self._created_workspaces[id] = WorkspaceConfig.from_dict(new_config_dict)
 
+    def get(
+        self,
+        *,
+        name: Optional[str] = None,
+        id: Optional[str] = None,  # noqa: A002
+        cloud: Optional[str] = None,
+        project: Optional[str] = None,
+    ) -> Workspace:
+        workspace_id, _ = self._resolve_to_workspace_model(
+            name=name, id=id, cloud=cloud, project=project
+        )
+        if workspace_id not in self._created_workspaces:
+            raise ValueError("Workspace not found.")
+
+        internal_workspace_model = self._created_workspaces[workspace_id]
+
+        return Workspace(
+            id=workspace_id,
+            name=internal_workspace_model.name or "fake_workspace_name",
+            config=internal_workspace_model,
+            state=self._workspace_status[workspace_id],
+        )
+
 
 @pytest.fixture()
 def fake_workspace_sdk() -> Generator[FakeWorkspaceSDK, None, None]:
@@ -798,3 +827,71 @@ class TestUpdate:
 
         workspace = fake_workspace_sdk._created_workspaces[workspace_id]
         assert workspace.name == name
+
+
+class TestGet:
+    def test_missing_arg(self, fake_workspace_sdk):
+        runner = CliRunner()
+        result = runner.invoke(get)
+        _assert_error_message(
+            result, message="Error: One of '--name' and '--id' must be provided."
+        )
+
+    def test_invalid_args(self, fake_workspace_sdk):
+        runner = CliRunner()
+        result = runner.invoke(create, ["-f", MINIMAL_CONFIG_PATH])
+        assert result.exit_code == 0, result.stdout
+
+        workspace_id = list(fake_workspace_sdk._created_workspaces.keys())[0]
+        workspace_name = list(fake_workspace_sdk._created_workspaces.values())[0].name
+
+        result = runner.invoke(get, ["-n", workspace_name, "--id", workspace_id])
+        _assert_error_message(
+            result, message="Only one of '--name' and '--id' can be provided."
+        )
+
+    def test_get_with_id(self, fake_workspace_sdk):
+        runner = CliRunner()
+        result = runner.invoke(create, ["-f", MINIMAL_CONFIG_PATH])
+        assert result.exit_code == 0, result.stdout
+
+        workspace_id = list(fake_workspace_sdk._created_workspaces.keys())[0]
+
+        result = runner.invoke(get, ["--id", workspace_id])
+        assert result.exit_code == 0, result.stdout
+        assert workspace_id in result.stdout
+
+    def test_get_with_name(self, fake_workspace_sdk):
+        runner = CliRunner()
+        result = runner.invoke(create, ["-f", MINIMAL_CONFIG_PATH])
+        assert result.exit_code == 0, result.stdout
+
+        workspace_id = list(fake_workspace_sdk._created_workspaces.keys())[0]
+        workspace_name = list(fake_workspace_sdk._created_workspaces.values())[0].name
+
+        result = runner.invoke(get, ["-n", workspace_name])
+        assert result.exit_code == 0, result.stdout
+        assert workspace_id in result.stdout
+
+    def test_verbose_flag(self, fake_workspace_sdk):
+        runner = CliRunner()
+
+        result = runner.invoke(create, ["-f", MINIMAL_CONFIG_PATH])
+        assert result.exit_code == 0, result.stdout
+        workspace_name = list(fake_workspace_sdk._created_workspaces.values())[0].name
+
+        # No verbose flag -- exclude details.
+        result = runner.invoke(get, ["-n", workspace_name])
+        assert result.exit_code == 0
+        assert "id" in result.stdout
+        assert "name" in result.stdout
+        assert "state" in result.stdout
+        assert "config" not in result.stdout
+
+        # Verbose flag -- include details.
+        result = runner.invoke(get, ["-n", workspace_name, "-v"])
+        assert result.exit_code == 0
+        assert "id" in result.stdout
+        assert "name" in result.stdout
+        assert "state" in result.stdout
+        assert "config" in result.stdout
