@@ -49,6 +49,7 @@ def get_mock_cloud():
         state="ACTIVE",
         is_bring_your_own_resource=False,
         is_default=False,
+        customer_aggregated_logs_config_id="calc_fake_id",
     )
     return mock_cloud
 
@@ -1202,9 +1203,35 @@ def test_update_template_with_memorydb():
 Resources:
 Outputs:
 """
-    assert (
-        update_template_with_memorydb(mock_template_body, 2)
-        == """
+
+    mock_azs = {
+        "use1-az1": "us-east-1a",
+        "use1-az2": "us-east-1b",
+        "use1-az3": "us-east-1c",
+        "use1-az4": "us-east-1d",
+        "use1-az5": "us-east-1e",
+        "use1-az6": "us-east-1f",
+    }
+
+    with patch.multiple(
+        "anyscale.utils.cloud_update_utils",
+        get_availability_zones=Mock(return_value=mock_azs),
+    ):
+        update_template_with_memorydb(mock_template_body, "us-east-1", mock_azs)
+        assert (
+            update_template_with_memorydb(
+                mock_template_body,
+                "us-east-1",
+                {
+                    "us-east-1a": "Subnet0",
+                    "us-east-1b": "Subnet1",
+                    "us-east-1c": "Subnet2",
+                    "us-east-1d": "Subnet3",
+                    "us-east-1e": "Subnet4",
+                    "us-east-1f": "Subnet5",
+                },
+            )
+            == """
 Resources:
   MemoryDBSubnetGroup:
     Type: AWS::MemoryDB::SubnetGroup
@@ -1212,8 +1239,9 @@ Resources:
       Description: Anyscale managed MemoryDB subnet group
       SubnetGroupName: !Ref AWS::StackName
       SubnetIds:
-        - !Ref Subnet0
         - !Ref Subnet1
+        - !Ref Subnet3
+        - !Ref Subnet5
       Tags:
         - Key: anyscale-cloud-id
           Value: !Ref CloudID
@@ -1255,7 +1283,7 @@ Outputs:
         ClusterEndpointAddress: !GetAtt MemoryDB.ClusterEndpoint.Address
 
 """
-    )
+        )
 
 
 @pytest.mark.parametrize(
@@ -1346,6 +1374,14 @@ def test_get_or_create_memorydb(memorydb_exists: bool):
 
     mock_handler.get_cloudformation_stack = Mock(return_value=mock_stack)
     mock_handler.get_template_body = Mock(return_value=mock_template)
+    mock_handler.get_processed_template_body = Mock(
+        return_value={
+            "Resources": {
+                "Subnet0": {"Properties": {"AvailabilityZone": "us-east-1b",},},
+                "Subnet1": {"Properties": {"AvailabilityZone": "us-east-1a",},},
+            },
+        }
+    )
     mock_handler.update_cloudformation_stack = Mock()
     mock_memorydb_id = "mock_id"
     mock_handler.get_resource = Mock(
@@ -1363,7 +1399,7 @@ def test_get_or_create_memorydb(memorydb_exists: bool):
         modify_memorydb_parameter_group=Mock(),
     ):
         result = get_or_create_memorydb(
-            "mock_stack_name", "mock_region", 2, CloudSetupLogger(), True
+            "mock_region", "mock_stack_name", CloudSetupLogger(), True
         )
         assert result == mock_memorydb_id
         if memorydb_exists:
